@@ -39,6 +39,7 @@
 #include <QUrl>
 #include <QAction>
 #include <QIcon>
+#include <QMenuBar>
 
 #include <KAcceleratorManager>
 #include <KActionCollection>
@@ -226,6 +227,7 @@ void ConnectionEditor::initializeMenu()
     kAction->setEnabled(false);
     connect(kAction, &QAction::triggered, this, &ConnectionEditor::exportVpn);
 
+    m_menuBarAction = KStandardAction::showMenubar(this, SLOT(slotShowMenuBar()), actionCollection());
     KStandardAction::keyBindings(guiFactory(), SLOT(configureShortcuts()), actionCollection());
     KStandardAction::quit(this, SLOT(close()), actionCollection());
 
@@ -539,6 +541,11 @@ void ConnectionEditor::slotItemDoubleClicked(const QModelIndex &index)
     editor->show();
 }
 
+void ConnectionEditor::slotShowMenuBar()
+{
+    menuBar()->setVisible(m_menuBarAction->isChecked());
+}
+
 void ConnectionEditor::importSecretsFromPlainTextFiles()
 {
     const QString secretsDirectory = QStandardPaths::locate(QStandardPaths::DataLocation, "networkmanagement/secrets/", QStandardPaths::LocateDirectory);
