@@ -113,7 +113,7 @@ void BluetoothMonitor::addBluetoothConnection(const QString& bdAddr, const QStri
             }
         }
 
-        Q_FOREACH(QDBusPendingCallWatcher *getPropertiesWatcher, *getPropertiesWatchers) {
+        Q_FOREACH (QDBusPendingCallWatcher *getPropertiesWatcher, *getPropertiesWatchers) {
             connect(getPropertiesWatcher, &QDBusPendingCallWatcher::finished, [this, bdAddr, service, getPropertiesWatchers](QDBusPendingCallWatcher *watcher) {
                 // remove it from the shared set
                 getPropertiesWatchers->remove(watcher);
@@ -138,7 +138,7 @@ void BluetoothMonitor::addBluetoothConnection(const QString& bdAddr, const QStri
                 }
 
                 // Delete all other watcher since we already find the first match address
-                Q_FOREACH(QDBusPendingCallWatcher *getPropertiesWatcher, *getPropertiesWatchers) {
+                Q_FOREACH (QDBusPendingCallWatcher *getPropertiesWatcher, *getPropertiesWatchers) {
                     delete getPropertiesWatcher;
                 }
                 getPropertiesWatchers->clear();
@@ -149,7 +149,7 @@ void BluetoothMonitor::addBluetoothConnection(const QString& bdAddr, const QStri
 
                 // check support on dun and nap
                 bool dun = false, nap = false;
-                Q_FOREACH(const QString &u, properties["UUIDs"].toStringList()) {
+                Q_FOREACH (const QString &u, properties["UUIDs"].toStringList()) {
                     QUuid uuid(u);
                     if (uuid.data1 == 0x1103) {
                         dun = true;
@@ -184,7 +184,7 @@ void BluetoothMonitor::addBluetoothConnection(const QString& bdAddr, const QStri
                     }
 
                     bool exists = false;
-                    Q_FOREACH(const NetworkManager::Connection::Ptr &con, NetworkManager::listConnections()) {
+                    Q_FOREACH (const NetworkManager::Connection::Ptr &con, NetworkManager::listConnections()) {
                         if (con && con->settings() && con->settings()->connectionType() == NetworkManager::ConnectionSettings::Bluetooth) {
                             NetworkManager::BluetoothSetting::Ptr btSetting = con->settings()->setting(NetworkManager::Setting::Bluetooth).staticCast<NetworkManager::BluetoothSetting>();
                             if (btSetting->bluetoothAddress() == NetworkManager::macAddressFromString(bdAddr)) {
@@ -209,37 +209,44 @@ void BluetoothMonitor::addBluetoothConnection(const QString& bdAddr, const QStri
 #if WITH_MODEMMANAGER_SUPPORT
                         else if (service == QLatin1String("dun")) {
                             QPointer<MobileConnectionWizard> mobileConnectionWizard = new MobileConnectionWizard(NetworkManager::ConnectionSettings::Bluetooth);
-                            if (mobileConnectionWizard->exec() == QDialog::Accepted && mobileConnectionWizard->getError() == MobileProviders::Success) {
-                                qCDebug(PLASMA_NM) << "Mobile broadband wizard finished:" << mobileConnectionWizard->type() << mobileConnectionWizard->args();
-                                if (mobileConnectionWizard->args().count() == 2) { //GSM or CDMA
-                                    qCDebug(PLASMA_NM) << "Creating new DUN connection for BT device:" << bdAddr;
+                            connect(mobileConnectionWizard.data(), &MobileConnectionWizard::accepted,
+                                    [bdAddr, deviceName, mobileConnectionWizard, this] () {
+                                        if (mobileConnectionWizard->getError() == MobileProviders::Success) {
+                                            qCDebug(PLASMA_NM) << "Mobile broadband wizard finished:" << mobileConnectionWizard->type() << mobileConnectionWizard->args();
+                                            if (mobileConnectionWizard->args().count() == 2) { //GSM or CDMA
+                                                qCDebug(PLASMA_NM) << "Creating new DUN connection for BT device:" << bdAddr;
 
-                                    QVariantMap tmp = qdbus_cast<QVariantMap>(mobileConnectionWizard->args().value(1));
-                                    NetworkManager::ConnectionSettings connectionSettings(NetworkManager::ConnectionSettings::Bluetooth, NM_BT_CAPABILITY_DUN);
-                                    connectionSettings.setUuid(NetworkManager::ConnectionSettings::createNewUuid());
-                                    connectionSettings.setId(deviceName);
-                                    NetworkManager::BluetoothSetting::Ptr btSetting = connectionSettings.setting(NetworkManager::Setting::Bluetooth).staticCast<NetworkManager::BluetoothSetting>();
-                                    btSetting->setBluetoothAddress(NetworkManager::macAddressFromString(bdAddr));
-                                    btSetting->setProfileType(NetworkManager::BluetoothSetting::Dun);
-                                    btSetting->setInitialized(true);
+                                                QVariantMap tmp = qdbus_cast<QVariantMap>(mobileConnectionWizard->args().value(1));
+                                                NetworkManager::ConnectionSettings connectionSettings(NetworkManager::ConnectionSettings::Bluetooth, NM_BT_CAPABILITY_DUN);
+                                                connectionSettings.setUuid(NetworkManager::ConnectionSettings::createNewUuid());
+                                                connectionSettings.setId(deviceName);
+                                                NetworkManager::BluetoothSetting::Ptr btSetting = connectionSettings.setting(NetworkManager::Setting::Bluetooth).staticCast<NetworkManager::BluetoothSetting>();
+                                                btSetting->setBluetoothAddress(NetworkManager::macAddressFromString(bdAddr));
+                                                btSetting->setProfileType(NetworkManager::BluetoothSetting::Dun);
+                                                btSetting->setInitialized(true);
 
-                                    if (mobileConnectionWizard->type() == NetworkManager::ConnectionSettings::Gsm) {
-                                        connectionSettings.setting(NetworkManager::Setting::Gsm)->fromMap(tmp);
-                                        connectionSettings.setting(NetworkManager::Setting::Gsm)->setInitialized(true);
-                                    } else if (mobileConnectionWizard->type() == NetworkManager::ConnectionSettings::Cdma) {
-                                        connectionSettings.setting(NetworkManager::Setting::Cdma)->fromMap(tmp);
-                                        connectionSettings.setting(NetworkManager::Setting::Cdma)->setInitialized(true);
-                                    }
+                                                if (mobileConnectionWizard->type() == NetworkManager::ConnectionSettings::Gsm) {
+                                                    connectionSettings.setting(NetworkManager::Setting::Gsm)->fromMap(tmp);
+                                                    connectionSettings.setting(NetworkManager::Setting::Gsm)->setInitialized(true);
+                                                } else if (mobileConnectionWizard->type() == NetworkManager::ConnectionSettings::Cdma) {
+                                                    connectionSettings.setting(NetworkManager::Setting::Cdma)->fromMap(tmp);
+                                                    connectionSettings.setting(NetworkManager::Setting::Cdma)->setInitialized(true);
+                                                }
 
-                                    qCDebug(PLASMA_NM) << "Adding DUN connection" << connectionSettings;
+                                                qCDebug(PLASMA_NM) << "Adding DUN connection" << connectionSettings;
 
-                                    NetworkManager::addConnection(connectionSettings.toMap());
-                                }
-                            }
-
-                            if (mobileConnectionWizard) {
-                                delete mobileConnectionWizard;
-                            }
+                                                NetworkManager::addConnection(connectionSettings.toMap());
+                                            }
+                                        }
+                                    });
+                            connect(mobileConnectionWizard.data(), &MobileConnectionWizard::finished,
+                                    [mobileConnectionWizard] () {
+                                        if (mobileConnectionWizard) {
+                                            mobileConnectionWizard->deleteLater();
+                                        }
+                                    });
+                            mobileConnectionWizard->setModal(true);
+                            mobileConnectionWizard->show();
                         }
 #endif
                     }
