@@ -161,7 +161,7 @@ void IPv4Widget::loadConfig(const NetworkManager::Setting::Ptr &setting)
 
     // dns
     QStringList tmp;
-    Q_FOREACH(const QHostAddress & addr, ipv4Setting->dns()) {
+    Q_FOREACH (const QHostAddress & addr, ipv4Setting->dns()) {
         tmp.append(addr.toString());
     }
     m_ui->dns->setText(tmp.join(","));
@@ -170,7 +170,7 @@ void IPv4Widget::loadConfig(const NetworkManager::Setting::Ptr &setting)
     m_ui->dhcpClientId->setText(ipv4Setting->dhcpClientId());
 
     // addresses
-    Q_FOREACH(const NetworkManager::IpAddress &addr, ipv4Setting->addresses()) {
+    Q_FOREACH (const NetworkManager::IpAddress &addr, ipv4Setting->addresses()) {
         QList<QStandardItem *> item;
         item << new QStandardItem(addr.ip().toString())
              << new QStandardItem(addr.netmask().toString())
@@ -220,7 +220,7 @@ QVariantMap IPv4Widget::setting(bool agentOwned) const
     if (m_ui->dns->isEnabled() && !m_ui->dns->text().isEmpty()) {
         QStringList tmp = m_ui->dns->text().split(',');
         QList<QHostAddress> tmpAddrList;
-        Q_FOREACH(const QString & str, tmp) {
+        Q_FOREACH (const QString & str, tmp) {
             QHostAddress addr(str);
             if (!addr.isNull())
                 tmpAddrList.append(addr);
@@ -398,15 +398,20 @@ void IPv4Widget::slotRoutesDialog()
         dlg->setIgnoreAutoRoutes(m_tmpIpv4Setting.ignoreAutoRoutes());
     }
 
-    if (dlg->exec() == QDialog::Accepted) {
-        m_tmpIpv4Setting.setRoutes(dlg->routes());
-        m_tmpIpv4Setting.setNeverDefault(dlg->neverDefault());
-        m_tmpIpv4Setting.setIgnoreAutoRoutes(dlg->ignoreautoroutes());
-    }
-
-    if (dlg) {
-        dlg->deleteLater();
-    }
+    connect(dlg.data(), &QDialog::accepted,
+            [dlg, this] () {
+                m_tmpIpv4Setting.setRoutes(dlg->routes());
+                m_tmpIpv4Setting.setNeverDefault(dlg->neverDefault());
+                m_tmpIpv4Setting.setIgnoreAutoRoutes(dlg->ignoreautoroutes());
+            });
+    connect(dlg.data(), &QDialog::finished,
+            [dlg] () {
+                if (dlg) {
+                    dlg->deleteLater();
+                }
+            });
+    dlg->setModal(true);
+    dlg->show();
 }
 
 void IPv4Widget::slotDnsServers()
@@ -421,18 +426,22 @@ void IPv4Widget::slotDnsServers()
     listWidget->setItems(m_ui->dns->text().split(',').replaceInStrings(" ", ""));
     dialog->layout()->addWidget(listWidget);
     dialog->layout()->addWidget(buttons);
-
-    if (dialog->exec() == QDialog::Accepted) {
-        QString text = listWidget->items().join(",");
-        if (text.endsWith(',')) {
-            text.chop(1);
-        }
-        m_ui->dns->setText(text);
-    }
-
-    if (dialog) {
-        dialog->deleteLater();
-    }
+    connect(dialog.data(), &QDialog::accepted,
+            [listWidget, this] () {
+                QString text = listWidget->items().join(",");
+                if (text.endsWith(',')) {
+                    text.chop(1);
+                }
+                m_ui->dns->setText(text);
+            });
+    connect(dialog.data(), &QDialog::finished,
+            [dialog] () {
+                if (dialog) {
+                    dialog->deleteLater();
+                }
+            });
+    dialog->setModal(true);
+    dialog->show();
 }
 
 void IPv4Widget::slotDnsDomains()
@@ -447,18 +456,22 @@ void IPv4Widget::slotDnsDomains()
     listWidget->setItems(m_ui->dnsSearch->text().split(',').replaceInStrings(" ", ""));
     dialog->layout()->addWidget(listWidget);
     dialog->layout()->addWidget(buttons);
-
-    if (dialog->exec() == QDialog::Accepted) {
-        QString text = listWidget->items().join(",");
-        if (text.endsWith(',')) {
-            text.chop(1);
-        }
-        m_ui->dnsSearch->setText(text);
-    }
-
-    if (dialog) {
-        dialog->deleteLater();
-    }
+    connect(dialog.data(), &QDialog::accepted,
+            [listWidget, this] () {
+                QString text = listWidget->items().join(",");
+                if (text.endsWith(',')) {
+                    text.chop(1);
+                }
+                m_ui->dnsSearch->setText(text);
+            });
+    connect(dialog.data(), &QDialog::finished,
+            [dialog] () {
+                if (dialog) {
+                    dialog->deleteLater();
+                }
+            });
+    dialog->setModal(true);
+    dialog->show();
 }
 
 bool IPv4Widget::isValid() const
@@ -481,7 +494,7 @@ bool IPv4Widget::isValid() const
 
     if (!m_ui->dns->text().isEmpty() && (m_ui->method->currentIndex() == Automatic || m_ui->method->currentIndex() == Manual || m_ui->method->currentIndex() == AutomaticOnlyIP)) {
         const QStringList tmp = m_ui->dns->text().split(',');
-        Q_FOREACH(const QString & str, tmp) {
+        Q_FOREACH (const QString & str, tmp) {
             QHostAddress addr(str);
             if (addr.isNull()) {
                 return false;
