@@ -149,14 +149,14 @@ void IPv6Widget::loadConfig(const NetworkManager::Setting::Ptr &setting)
 
     // dns
     QStringList tmp;
-    Q_FOREACH(const QHostAddress & addr, ipv6Setting->dns()) {
+    Q_FOREACH (const QHostAddress & addr, ipv6Setting->dns()) {
         tmp.append(addr.toString());
     }
     m_ui->dns->setText(tmp.join(","));
     m_ui->dnsSearch->setText(ipv6Setting->dnsSearch().join(","));
 
     // addresses
-    Q_FOREACH(const NetworkManager::IpAddress &address, ipv6Setting->addresses()) {
+    Q_FOREACH (const NetworkManager::IpAddress &address, ipv6Setting->addresses()) {
         QList<QStandardItem *> item;
 
         item << new QStandardItem(address.ip().toString())
@@ -212,7 +212,7 @@ QVariantMap IPv6Widget::setting(bool agentOwned) const
     if (m_ui->dns->isEnabled() && !m_ui->dns->text().isEmpty()) {
         QStringList tmp = m_ui->dns->text().split(',');
         QList<QHostAddress> tmpAddrList;
-        Q_FOREACH(const QString & str, tmp) {
+        Q_FOREACH (const QString & str, tmp) {
             QHostAddress addr(str);
             if (!addr.isNull())
                 tmpAddrList.append(addr);
@@ -388,15 +388,20 @@ void IPv6Widget::slotRoutesDialog()
         dlg->setIgnoreAutoRoutes(m_tmpIpv6Setting.ignoreAutoRoutes());
     }
 
-    if (dlg->exec() == QDialog::Accepted) {
-        m_tmpIpv6Setting.setRoutes(dlg->routes());
-        m_tmpIpv6Setting.setNeverDefault(dlg->neverDefault());
-        m_tmpIpv6Setting.setIgnoreAutoRoutes(dlg->ignoreautoroutes());
-    }
-
-    if (dlg) {
-        dlg->deleteLater();
-    }
+    connect(dlg.data(), &QDialog::accepted,
+            [dlg, this] () {
+                m_tmpIpv6Setting.setRoutes(dlg->routes());
+                m_tmpIpv6Setting.setNeverDefault(dlg->neverDefault());
+                m_tmpIpv6Setting.setIgnoreAutoRoutes(dlg->ignoreautoroutes());
+            });
+    connect(dlg.data(), &QDialog::finished,
+            [dlg] () {
+                if (dlg) {
+                    dlg->deleteLater();
+                }
+            });
+    dlg->setModal(true);
+    dlg->show();
 }
 
 void IPv6Widget::slotDnsServers()
@@ -411,18 +416,22 @@ void IPv6Widget::slotDnsServers()
     listWidget->setItems(m_ui->dns->text().split(',').replaceInStrings(" ", ""));
     dialog->layout()->addWidget(listWidget);
     dialog->layout()->addWidget(buttons);
-
-    if (dialog->exec() == QDialog::Accepted) {
-        QString text = listWidget->items().join(",");
-        if (text.endsWith(',')) {
-            text.chop(1);
-        }
-        m_ui->dns->setText(text);
-    }
-
-    if (dialog) {
-        dialog->deleteLater();
-    }
+    connect(dialog.data(), &QDialog::accepted,
+            [listWidget, this] () {
+                QString text = listWidget->items().join(",");
+                if (text.endsWith(',')) {
+                    text.chop(1);
+                }
+                m_ui->dns->setText(text);
+            });
+    connect(dialog.data(), &QDialog::finished,
+            [dialog] () {
+                if (dialog) {
+                    dialog->deleteLater();
+                }
+            });
+    dialog->setModal(true);
+    dialog->show();
 }
 
 void IPv6Widget::slotDnsDomains()
@@ -437,18 +446,22 @@ void IPv6Widget::slotDnsDomains()
     listWidget->setItems(m_ui->dnsSearch->text().split(',').replaceInStrings(" ", ""));
     dialog->layout()->addWidget(listWidget);
     dialog->layout()->addWidget(buttons);
-
-    if (dialog->exec() == QDialog::Accepted) {
-        QString text = listWidget->items().join(",");
-        if (text.endsWith(',')) {
-            text.chop(1);
-        }
-        m_ui->dnsSearch->setText(text);
-    }
-
-    if (dialog) {
-        dialog->deleteLater();
-    }
+    connect(dialog.data(), &QDialog::accepted,
+            [listWidget, this] () {
+                QString text = listWidget->items().join(",");
+                if (text.endsWith(',')) {
+                    text.chop(1);
+                }
+                m_ui->dnsSearch->setText(text);
+            });
+    connect(dialog.data(), &QDialog::finished,
+            [dialog] () {
+                if (dialog) {
+                    dialog->deleteLater();
+                }
+            });
+    dialog->setModal(true);
+    dialog->show();
 }
 
 bool IPv6Widget::isValid() const
@@ -471,7 +484,7 @@ bool IPv6Widget::isValid() const
 
     if (!m_ui->dns->text().isEmpty() && (m_ui->method->currentIndex() == Automatic || m_ui->method->currentIndex() == Manual || m_ui->method->currentIndex() == AutomaticOnlyIP)) {
         const QStringList tmp = m_ui->dns->text().split(',');
-        Q_FOREACH(const QString & str, tmp) {
+        Q_FOREACH (const QString & str, tmp) {
             QHostAddress addr(str);
             if (addr.isNull()) {
                 return false;
