@@ -57,7 +57,6 @@ OpenVpnAdvancedWidget::OpenVpnAdvancedWidget(const NetworkManager::VpnSetting::P
     d(new Private)
 {
     m_ui->setupUi(this);
-    m_ui->kurlTlsAuthKey->setMode(KFile::LocalOnly);
 
     setWindowTitle(i18nc("@title: window advanced openvpn properties", "Advanced OpenVPN properties"));
 
@@ -335,7 +334,11 @@ NetworkManager::VpnSetting::Ptr OpenVpnAdvancedWidget::setting() const
     }
 
     if (m_ui->chkRemoteCertTls->isChecked()) {
-        data.insert(QLatin1String(NM_OPENVPN_KEY_REMOTE_CERT_TLS), m_ui->cmbRemoteCertTls->currentText().toLower());
+        if (m_ui->cmbRemoteCertTls->currentIndex() == 0) {
+            data.insert(QLatin1String(NM_OPENVPN_KEY_REMOTE_CERT_TLS), QLatin1String("server"));
+        } else {
+            data.insert(QLatin1String(NM_OPENVPN_KEY_REMOTE_CERT_TLS), QLatin1String("client"));
+        }
     }
 
     if (m_ui->useExtraTlsAuth->isChecked()) {
